==> moodle-2.2.11.tgz: moodle/blocks/tags/lang/en/block_tags.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_tags', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   block_tags
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['add'] = 'Add';
$string['alltags'] = 'All tags:';
$string['alltags1'] = 'all tags';
$string['alltags2'] = 'Show all tags (user profile, blogs and course tags)';
$string['arrowtitle'] = 'Click here to enter the suggested text (grey letters).';
$string['communitytags'] = 'Community tags:';
$string['communitytags1'] = 'community tags';
$string['communitytags2'] = 'Show all user created course tags';
$string['coursetags'] = 'Course tags:';
$string['coursetags1'] = 'course tags';
$string['coursetags2'] = 'Show tags for this course';
$string['disabledtags'] = 'Tags are disabled';
$string['edit'] = 'edit...';
$string['editdeletemytag'] = 'Delete tag from this course:';
$string['editmytags'] = 'My tags - shortcuts to all your tagged courses.';
$string['editmytagsfor'] = 'Edit my tags for {$a}';
$string['editnopersonaltags'] = 'No personal tags have been created yet.';
$string['edittags'] = 'Edit my tags...';
$string['edittagthisunit'] = 'Add tag to this course:';
$string['editthiscoursetags'] = 'My tags for this course are {$a}';
$string['edittitle'] = 'My tags';
$string['entries'] = 'entries';
$string['entry'] = 'entry';
$string['jserror1'] = 'Tags must have between one and 50 characters. Please adjust your tag.';
$string['jserror2'] = 'Tags cannot contain these special characters - backslash, less than (<) or greater than (>). Please adjust your tag.';
$string['login'] = 'log in';
$string['more'] = 'more...';
$string['moreorder'] = 'Order:';
$string['moreorderalpha'] = 'Alphabetical';
$string['moreorderdate'] = 'Date created';
$string['moreorderpop'] = 'Popularity';
$string['moreshow'] = 'Show:';
$string['moreshowalltags'] = 'All tags';
$string['moreshowcommtags'] = 'Community tags';
$string['moreshowcoursetags'] = 'Tags for \'{$a}\'';
$string['moreshowmytags'] = 'My tags';
$string['moreshowofficialtags'] = 'Official tags';
$string['moretags'] = 'Show and filter more tags';
$string['moretitle'] = 'More tags';
$string['morewelcome'] = 'Welcome to the \'More tags\' tag cloud.
Tags are user created links to things. Tags allow you to categorise and link things
like your favourite courses, your blogs or your profile with your own words.
Different groups of tags may be displayed with the links on the \'Show:\' line,
and may be reordered with the links on the \'Order:\' line.';
$string['mycoursetags'] = 'My course tags:';
$string['mycoursetag1'] = 'Show my course tags';
$string['mycoursetag2'] = 'my course tags';
$string['mytags'] = 'My tags:';
$string['mytags1'] = 'my tags';
$string['mytags2'] = 'Show my personal tags';
$string['notagsyet'] = 'No tags yet';
$string['officialtags'] = 'Official course tags:';
$string['officialtags1'] = 'official tags';
$string['officialtags2'] = 'Show official course tags';
$string['please'] = 'Please';
$string['pluginname'] = 'Tags';
$string['select'] = 'Select...';
$string['showcoursetags'] = 'Show course tags';
$string['showcoursetagsdef'] = 'Display the course tagging features in the tags block, allowing students to tag courses.';
$string['suggestedtagthisunit'] = 'Suggested tag to this course:';
$string['tags'] = 'tags';
$string['tagthisunit'] = 'Tag this course:';
$string['tagunits'] = 'to tag your favourite courses';

==> moodle-2.9.5.tgz: moodle/blocks/tags/lang/en/block_tags.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_tags', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   block_tags
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['add'] = 'Add';
$string['alltags'] = 'All tags:';
$string['arrowtitle'] = 'Click here to enter the suggested text (grey letters).';
$string['configtitle'] = 'Block title';
$string['coursetags'] = 'Course tags:';
$string['disabledtags'] = 'Tags are disabled';
$string['defaultdisplay'] = 'Tag type to display';
$string['edit'] = 'edit...';
$string['editdeletemytag'] = 'Delete tag from this course:';
$string['editmytags'] = 'My tags - shortcuts to all your tagged courses.';
$string['editmytagsfor'] = 'Edit my tags for {$a}';
$string['editnopersonaltags'] = 'No personal tags have been created yet.';
$string['edittags'] = 'Edit my tags...';
$string['edittagthisunit'] = 'Add tag to this course:';
$string['editthiscoursetags'] = 'My tags for this course are {$a}';
$string['edittitle'] = 'My tags';
$string['entries'] = 'entries';
$string['entry'] = 'entry';
$string['jserror1'] = 'Tags must have between one and 50 characters. Please adjust your tag.';
$string['jserror2'] = 'Tags cannot contain these special characters - backslash, less than (<) or greater than (>). Please adjust your tag.';
$string['login'] = 'log in';
$string['more'] = 'more...';
$string['moreorder'] = 'Order:';
$string['moreorderalpha'] = 'Alphabetical';
$string['moreorderdate'] = 'Date created';
$string['moreorderpop'] = 'Popularity';
$string['moreshow'] = 'Show:';
$string['moreshowalltags'] = 'All tags';
$string['moreshowcommtags'] = 'Non-official tags';
$string['moreshowcoursetags'] = 'Tags for \'{$a}\'';
$string['moreshowmytags'] = 'My tags';
$string['moreshowofficialtags'] = 'Official tags';
$string['moretags'] = 'Show and filter more tags';
$string['moretitle'] = 'More tags';
$string['morewelcome'] = 'Welcome to the \'More tags\' tag cloud.
Tags are user created links to things. Tags allow you to categorise and link things
like your favourite courses, your blogs or your profile with your own words.
Different groups of tags may be displayed with the links on the \'Show:\' line,
and may be reordered with the links on the \'Order:\' line.';
$string['mycoursetags'] = 'My course tags:';
$string['mytags'] = 'My tags:';
$string['notagsyet'] = 'No tags yet';
$string['please'] = 'Please';
$string['pluginname'] = 'Tags';
$string['select'] = 'Select...';
$string['showcoursetags'] = 'Show course tags';
$string['showcoursetagsdef'] = 'Display the course tagging features in the tags block, allowing students to tag courses.';
$string['suggestedtagthisunit'] = 'Suggested tag to this course:';
$string['tags'] = 'tags';
$string['tags:addinstance'] = 'Add a new tags block';
$string['tags:myaddinstance'] = 'Add a new tags block to Dashboard';
$string['tagthisunit'] = 'Tag this course:';
$string['tagunits'] = 'to tag your favourite courses';
